// Copyright (c) 2021 Razeware LLC
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// Notwithstanding the foregoing, you may not use, copy, modify, merge, publish,
// distribute, sublicense, create a derivative work, and/or sell copies of the
// Software in any work that is designed, intended, or marketed for pedagogical
// or instructional purposes related to programming, coding, application
// development, or information technology.  Permission for such use, copying,
// modification, merger, publication, distribution, sublicensing, creation of
// derivative works, or sale is expressly withheld.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

import 'dart:math' as math;

import 'package:flutter/material.dart';

class ArcsCurvesPainter extends CustomPainter {
  final curvesPaint = Paint()
    ..strokeWidth = 5
    ..color = Colors.greenAccent[700]!
    ..style = PaintingStyle.stroke;

  @override
  void paint(Canvas canvas, Size size) {
    const arcCenter = Offset(200, 80);
    final arcRect = Rect.fromCircle(center: arcCenter, radius: 75);
    final startAngle = degreesToRadians(10);
    final sweepAngle = degreesToRadians(-90);
    canvas.drawArc(arcRect, startAngle, sweepAngle, false, curvesPaint);

    // Quadratic Bézier
    final qCurve1 = Path()
      ..moveTo(50, 150)
      ..relativeQuadraticBezierTo(100, -100, 300, 0);
    canvas.drawPath(qCurve1, curvesPaint..color = Colors.deepPurpleAccent);

    final qCurve2 = Path()
      ..moveTo(0, 150)
      ..relativeQuadraticBezierTo(150, 300, 300, 100);
    canvas.drawPath(qCurve2, curvesPaint..color = Colors.blue);

    // Cubic Bézier
    final cCurve1 = Path()
      ..moveTo(0, 450)
      ..relativeCubicTo(50, -100, 250, -100, 300, 0);
    canvas.drawPath(cCurve1, curvesPaint..color = Colors.black);

    final cCurve2 = Path()
      ..moveTo(380, 300)
      ..relativeCubicTo(0, 450, -300, 300, -150, 250);
    canvas.drawPath(cCurve2, curvesPaint..color = Colors.pink);


  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) => false;

  double degreesToRadians(double degrees) {
    return (degrees * math.pi) / 180;
  }
}
